@@ -5,6 +5,7 @@ package Paws::AutoScaling::DescribePolicies {
   has MaxRecords => (is => 'ro', isa => 'Int');
   has NextToken => (is => 'ro', isa => 'Str');
   has PolicyNames => (is => 'ro', isa => 'ArrayRef[Str]');
+  has PolicyTypes => (is => 'ro', isa => 'ArrayRef[Str]');
 
   use MooseX::ClassAttribute;
 
@@ -101,6 +102,22 @@ no error.
 
 
 
+=head2 PolicyTypes => ArrayRef[Str]
+
+  
+
+One or more policy types. Valid values are C<SimpleScaling> and
+C<StepScaling>.
+
+
+
+
+
+
+
+
+
+
 
 
 =head1 SEE ALSO
