@@ -1,11 +1,11 @@
 package Paws::CloudSearchDomain::Facets {
   use Moose;
-  with 'Paws::API::StrToStrMapParser';
+  with 'Paws::API::StrToObjMapParser';
 
   use MooseX::ClassAttribute;
   class_has xml_keys =>(is => 'ro', default => 'key');
   class_has xml_values =>(is => 'ro', default => 'value');
 
-  has Map => (is => 'ro', isa => 'HashRef[Str]');
+  has Map => (is => 'ro', isa => 'HashRef[Paws::CloudSearchDomain::BucketInfo]');
 }
 1
