@@ -1,13 +1,15 @@
 
 package Paws::CognitoSync::DeleteDataset {
   use Moose;
-  has DatasetName => (is => 'ro', isa => 'Str', required => 1);
-  has IdentityId => (is => 'ro', isa => 'Str', required => 1);
-  has IdentityPoolId => (is => 'ro', isa => 'Str', required => 1);
+  has DatasetName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'DatasetName' , required => 1);
+  has IdentityId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'IdentityId' , required => 1);
+  has IdentityPoolId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'IdentityPoolId' , required => 1);
 
   use MooseX::ClassAttribute;
 
   class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteDataset');
+  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/identitypools/{IdentityPoolId}/identities/{IdentityId}/datasets/{DatasetName}');
+  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
   class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CognitoSync::DeleteDatasetResponse');
   class_has _result_key => (isa => 'Str', is => 'ro', default => 'DeleteDatasetResult');
 }
