@@ -120,14 +120,15 @@ Constraint: Range is 100 to 20000 for Provisioned IOPS (SSD) volumes
 
   
 
-The full ARN of the AWS Key Management Service (KMS) master key to use
-when creating the encrypted volume. This parameter is only required if
-you want to use a non-default master key; if this parameter is not
-specified, the default master key is used. The ARN contains the
-C<arn:aws:kms> namespace, followed by the region of the master key, the
-AWS account ID of the master key owner, the C<key> namespace, and then
-the master key ID. For example,
+The full ARN of the AWS Key Management Service (KMS) Customer Master
+Key (CMK) to use when creating the encrypted volume. This parameter is
+only required if you want to use a non-default CMK; if this parameter
+is not specified, the default CMK for EBS is used. The ARN contains the
+C<arn:aws:kms> namespace, followed by the region of the CMK, the AWS
+account ID of the CMK owner, the C<key> namespace, and then the CMK ID.
+For example,
 arn:aws:kms:I<us-east-1>:I<012345678910>:key/I<abcd1234-a123-456a-a12b-a123b4cd56ef>.
+If a C<KmsKeyId> is specified, the C<Encrypted> flag must also be set.
 
 
 
