@@ -1,7 +1,7 @@
 package Paws::EC2::ImportInstanceVolumeDetailItem {
   use Moose;
   has AvailabilityZone => (is => 'ro', isa => 'Str', xmlname => 'availabilityZone', traits => ['Unwrapped'], required => 1);
-  has BytesConverted => (is => 'ro', isa => 'Num', xmlname => 'bytesConverted', traits => ['Unwrapped'], required => 1);
+  has BytesConverted => (is => 'ro', isa => 'Int', xmlname => 'bytesConverted', traits => ['Unwrapped'], required => 1);
   has Description => (is => 'ro', isa => 'Str', xmlname => 'description', traits => ['Unwrapped']);
   has Image => (is => 'ro', isa => 'Paws::EC2::DiskImageDescription', xmlname => 'image', traits => ['Unwrapped'], required => 1);
   has Status => (is => 'ro', isa => 'Str', xmlname => 'status', traits => ['Unwrapped'], required => 1);
