@@ -298,6 +298,19 @@ Returns: a L<Paws::ECS::DeregisterContainerInstanceResponse> instance
 Deregisters an Amazon ECS container instance from the specified
 cluster. This instance will no longer be available to run tasks.
 
+If you intend to use the container instance for some other purpose
+after deregistration, you should stop all of the tasks running on the
+container instance before deregistration to avoid any orphaned tasks
+from consuming resources.
+
+Deregistering a container instance removes the instance from a cluster,
+but it does not terminate the EC2 instance; if you are finished using
+the instance, be sure to terminate it in the Amazon EC2 console to stop
+billing.
+
+When you terminate a container instance, it is automatically
+deregistered from your cluster.
+
 
 
 
@@ -599,7 +612,7 @@ and C<desiredStatus> parameters.
 
 
 
-=head2 RegisterContainerInstance([cluster => Str, instanceIdentityDocument => Str, instanceIdentityDocumentSignature => Str, totalResources => ArrayRef[Paws::ECS::Resource], versionInfo => Paws::ECS::VersionInfo])
+=head2 RegisterContainerInstance([cluster => Str, containerInstanceArn => Str, instanceIdentityDocument => Str, instanceIdentityDocumentSignature => Str, totalResources => ArrayRef[Paws::ECS::Resource], versionInfo => Paws::ECS::VersionInfo])
 
 Each argument is described in detail in: L<Paws::ECS::RegisterContainerInstance>
 
@@ -770,7 +783,17 @@ Returns: a L<Paws::ECS::UpdateContainerAgentResponse> instance
   
 
 Updates the Amazon ECS container agent on a specified container
-instance.
+instance. Updating the Amazon ECS container agent does not interrupt
+running tasks or services on the container instance. The process for
+updating the agent differs depending on whether your container instance
+was launched with the Amazon ECS-optimized AMI or another operating
+system.
+
+C<UpdateContainerAgent> requires the Amazon ECS-optimized AMI or Amazon
+Linux with the C<ecs-init> service installed and running. For help
+updating the Amazon ECS container agent on other operating systems, see
+Manually Updating the Amazon ECS Container Agent in the I<Amazon EC2
+Container Service Developer Guide>.
 
 
 
