@@ -38,7 +38,9 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
   
 
 The name of your cluster. If you do not specify a name for your
-cluster, you will create a cluster named C<default>.
+cluster, you will create a cluster named C<default>. Up to 255 letters
+(uppercase and lowercase), numbers, hyphens, and underscores are
+allowed.
 
 
 
@@ -53,7 +55,7 @@ cluster, you will create a cluster named C<default>.
 
 =head1 SEE ALSO
 
-This class forms part of L<Paws>, and documents parameters for CreateCluster in Paws::ECS
+This class forms part of L<Paws>, documenting arguments for method CreateCluster in L<Paws::ECS>
 
 =head1 BUGS and CONTRIBUTIONS
 
