@@ -9,6 +9,8 @@ package Paws::ElasticTranscoder::TestRole {
   use MooseX::ClassAttribute;
 
   class_has _api_call => (isa => 'Str', is => 'ro', default => 'TestRole');
+  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/2012-09-25/roleTests');
+  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'POST');
   class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ElasticTranscoder::TestRoleResponse');
   class_has _result_key => (isa => 'Str', is => 'ro', default => 'TestRoleResult');
 }
