@@ -1,13 +1,15 @@
 
 package Paws::Glacier::AbortMultipartUpload {
   use Moose;
-  has accountId => (is => 'ro', isa => 'Str', required => 1);
-  has uploadId => (is => 'ro', isa => 'Str', required => 1);
-  has vaultName => (is => 'ro', isa => 'Str', required => 1);
+  has accountId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'accountId' , required => 1);
+  has uploadId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'uploadId' , required => 1);
+  has vaultName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'vaultName' , required => 1);
 
   use MooseX::ClassAttribute;
 
   class_has _api_call => (isa => 'Str', is => 'ro', default => 'AbortMultipartUpload');
+  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/{accountId}/vaults/{vaultName}/multipart-uploads/{uploadId}');
+  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'DELETE');
   class_has _returns => (isa => 'Str', is => 'ro');
   class_has _result_key => (isa => 'Str', is => 'ro');
 }
@@ -39,10 +41,12 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
   
 
-The C<AccountId> is the AWS Account ID. You can specify either the AWS
-Account ID or optionally a '-', in which case Amazon Glacier uses the
-AWS Account ID associated with the credentials used to sign the
-request. If you specify your Account ID, do not include hyphens in it.
+The C<AccountId> value is the AWS account ID of the account that owns
+the vault. You can either specify an AWS account ID or optionally a
+single aposC<->apos (hyphen), in which case Amazon Glacier uses the AWS
+account ID associated with the credentials used to sign the request. If
+you use an account ID, do not include any hyphens (apos-apos) in the
+ID.
 
 
 
