@@ -39,10 +39,9 @@ Values for attributes that are native types (Int, String, Float, etc) can passed
 
   
 
-Use this parameter only when paginating results, and only in a
-subsequent request after you've received a response where the results
-are truncated. Set it to the value of the C<Marker> element in the
-response you just received.
+Use this parameter only when paginating results and only after you have
+received a response where the results are truncated. Set it to the
+value of the C<Marker> element in the response you just received.
 
 
 
@@ -57,11 +56,13 @@ response you just received.
 
   
 
-Use this parameter only when paginating results to indicate the maximum
-number of keys you want in the response. If there are additional keys
-beyond the maximum you specify, the C<IsTruncated> response element is
-C<true>. This parameter is optional. If you do not include it, it
-defaults to 100.
+Use this only when paginating results to indicate the maximum number of
+items you want in the response. If there are additional items beyond
+the maximum you specify, the C<IsTruncated> response element is
+C<true>.
+
+This parameter is optional. If you do not include it, it defaults to
+100.
 
 
 
