@@ -56,10 +56,9 @@ policies for.
 
   
 
-Use this only when paginating results, and only in a subsequent request
-after you've received a response where the results are truncated. Set
-it to the value of the C<Marker> element in the response you just
-received.
+Use this parameter only when paginating results and only after you have
+received a response where the results are truncated. Set it to the
+value of the C<Marker> element in the response you just received.
 
 
 
@@ -75,10 +74,12 @@ received.
   
 
 Use this only when paginating results to indicate the maximum number of
-policies you want in the response. If there are additional policies
-beyond the maximum you specify, the C<IsTruncated> response element is
-C<true>. This parameter is optional. If you do not include it, it
-defaults to 100.
+items you want in the response. If there are additional items beyond
+the maximum you specify, the C<IsTruncated> response element is
+C<true>.
+
+This parameter is optional. If you do not include it, it defaults to
+100.
 
 
 
