@@ -83,10 +83,10 @@ a key, or an alias name prefixed by "alias/".
 arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012
 
 =item * Alias ARN Example -
-arn:aws:kms:us-east-1:123456789012:/alias/MyAliasName
+arn:aws:kms:us-east-1:123456789012:alias/MyAliasName
 
 =item * Globally Unique Key ID Example -
-12345678-1234-1234-123456789012
+12345678-1234-1234-1234-123456789012
 
 =item * Alias Name Example - alias/MyAliasName
 
