@@ -12,7 +12,7 @@ package Paws::MachineLearning::MLModel {
   has Name => (is => 'ro', isa => 'Str');
   has ScoreThreshold => (is => 'ro', isa => 'Num');
   has ScoreThresholdLastUpdatedAt => (is => 'ro', isa => 'Str');
-  has SizeInBytes => (is => 'ro', isa => 'Num');
+  has SizeInBytes => (is => 'ro', isa => 'Int');
   has Status => (is => 'ro', isa => 'Str');
   has TrainingDataSourceId => (is => 'ro', isa => 'Str');
   has TrainingParameters => (is => 'ro', isa => 'Paws::MachineLearning::TrainingParameters');
