@@ -75,8 +75,11 @@ permissions that are in excess of those allowed by the access policy of
 the role that is being assumed. For more information, see Permissions
 for AssumeRoleWithSAML in I<Using Temporary Security Credentials>.
 
-The policy must be 2048 bytes or shorter, and its packed size must be
-less than 450 bytes.
+The policy plain text must be 2048 bytes or shorter. However, an
+internal conversion compresses it into a packed binary format with a
+separate limit. The PackedPolicySize response element indicates by
+percentage how close to the upper size limit the policy is, with 100%
+equaling the maximum allowed size.
 
 
 
