@@ -3,7 +3,7 @@ package Paws::StorageGateway::Tape {
   has Progress => (is => 'ro', isa => 'Num');
   has TapeARN => (is => 'ro', isa => 'Str');
   has TapeBarcode => (is => 'ro', isa => 'Str');
-  has TapeSizeInBytes => (is => 'ro', isa => 'Num');
+  has TapeSizeInBytes => (is => 'ro', isa => 'Int');
   has TapeStatus => (is => 'ro', isa => 'Str');
   has VTLDevice => (is => 'ro', isa => 'Str');
 }
